@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1593 2009-12-06 22:42:27Z beerli $
+$Id: data.c 1604 2010-02-05 19:33:37Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -472,7 +472,7 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
 	(*data)->datatype = (long *) mycalloc(loci, sizeof(long));
 	(*data)->numdatatypealloc = loci;
 	(*data)->numsublocialloc = loci;
-	(*data)->subloci = mycalloc(loci,sizeof(long));
+	(*data)->subloci = (long *) mycalloc(loci,sizeof(long));
     }
     else
     {
@@ -705,7 +705,7 @@ void set_datatype(char input, long locus, char ** locitypes, long *alloc)
   if(locus >= *alloc)
     {
       *alloc += SUBLOCICHUNKS;
-      *locitypes = myrealloc(*locitypes, sizeof(char) * (*alloc));
+      *locitypes = (char *) myrealloc(*locitypes, sizeof(char) * (*alloc));
     }
   (*locitypes)[locus] = input;
 }
@@ -767,9 +767,9 @@ read_sites (data_fmt * data, world_fmt *world)
 		    strcpy(data->locusname[locus],word+1);
 		    // what is this good for?
 		    if(!strcmp(word,input))
-		      val=strchr("bmsnuh", input[0]);
+		      val=strchr((char *) "bmsnuh", input[0]);
 		    else
-		      val=strchr("bmsnuh", input[1]);
+		      val=strchr((char *) "bmsnuh", input[1]);
 
 		    if(val==0)
 		      {
@@ -905,9 +905,9 @@ read_old_sites (data_fmt * data)
 		    data->locusname[locus] = (char *) mycalloc(strlen(word),sizeof(char));
 		    strcpy(data->locusname[locus],word+1);
 		    if(!strcmp(word,input))
-		      val=strchr("bmsnuh", input[0]);
+		      val=strchr((char *) "bmsnuh", input[0]);
 		    else
-		      val=strchr("bmsnuh", input[1]);
+		      val=strchr((char *) "bmsnuh", input[1]);
 
 
                     if(val==0)
