@@ -182,6 +182,11 @@ pdf_dictionary pdf_pages_get_resources(pdf_pages pages);
 
 int pdf_pages_get_rotate(pdf_pages pages);
 
+  /* BEERLI addition for missing set_rotate function*/
+  void pdf_pages_set_rotate(pdf_pages pages, int degree);
+  void pdf_page_set_rotate(pdf_page pages, int degree);
+
+
 pdf_pages pdf_pages_get_parent(pdf_pages pages);
 
 pdf_dictionary pdf_pages_get_resource(pdf_pages pages, 
@@ -499,7 +504,7 @@ void pdf_jpeg_image_free_image(pdf_jpeg_image image);
 /*----------------------------------------------------------------------------*/
 /*----- PdfDoc class ---------------------------------------------------------*/
 
-pdf_doc pdf_doc_new();
+pdf_doc pdf_doc_new(void);
 
 void pdf_doc_free(pdf_doc doc);
 
