@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1597 2010-01-20 14:46:30Z beerli $*/
+/* $Id: main.c 1677 2010-04-27 19:37:49Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -77,7 +77,7 @@
 
 #ifdef PRETTY
 #ifdef WIN32
-extern void set_haru_handler(void);
+#include "pretty-win32.h"
 #endif
 #endif
 
@@ -808,12 +808,19 @@ long  calculate_newpop_numpop(option_fmt *options, data_fmt *data)
   long i;
   long newnumpop=0;
   long numpop = data->numpop;
+  //  char *strsep(char **, const char *);
+#ifdef WIN32
+    // dev studio does not understand the #warning preprocessor directive, it uses pragma but I am not ready for that yet
+    //#warning "Windows version is hardcoded to not have more than 5000 populations"
+    long temp[5000];
+#else
   long temp[data->numpop];
+#endif
   //use order of populations {1,2,3,4,5,....} , do not start with zero!!
   //reset to options->newpops={1,1,2,1,2,3,4,...}
   if(options->newpops_numalloc < numpop)
     {
-      options->newpops = myrealloc(options->newpops,sizeof(long)*numpop);
+      options->newpops = (long *) myrealloc(options->newpops,sizeof(long)*numpop);
       for(i=options->newpops_numalloc;i<numpop;i++)
 	{
 	  options->newpops[i] = i+1;
@@ -881,15 +888,12 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #endif
   set_plot (options);
   EARTH->cold = TRUE; // this is the cold chain when we use heating, the hotter chains have FALSE
-  options->slice_sticksizes = mycalloc(data->numpop * data->numpop + 1, sizeof(MYREAL));
-  for(i=0;i<data->numpop * data->numpop;i++)
-  {
-    options->slice_sticksizes[i] = 1.0;
-  }
-  options->slice_sticksizes[i] = 1.0;
-#ifdef NEWVERSION
+  options->slice_sticksizes = (MYREAL *) mycalloc(data->numpop * data->numpop + 1, sizeof(MYREAL));
+  // init of options->slice_sticksizes
+  // deferred after world->bayes initialization in init_world() 
+
   calculate_newpop_numpop(options,data);
-#endif
+
   init_world (EARTH, data, options);
   //  set_meanmu(EARTH,options);
   if(EARTH->cold)
@@ -2395,7 +2399,33 @@ void print_burnin_stop(FILE *file, world_fmt **universe, option_fmt * options)
     pdf_burnin_stops(EARTH, maxreplicate);
 #endif
 }
-  
+
+MYREAL combine_scaling_factor(world_fmt *world)
+{ 
+  const long np = world->numpop2;
+  long pop;
+  long i;
+  MYREAL scaling_factor=0.0;
+  bayes_fmt * bayes = world->bayes;
+  for(i=0;i<np;i++)
+    {
+      if(bayes->map[i][1] == INVALID)
+	continue;
+      else
+	{
+	  pop  = bayes->map[i][1];
+	}
+      scaling_factor += exp(bayes->scaling_factors[pop] - bayes->maxmaxvala);
+      //printf("%f\n",scaling_factor);
+    }
+  scaling_factor = log(scaling_factor) + bayes->maxmaxvala;
+  if(world->options->has_bayesfile)
+    {
+      printf("# Scaling factor %20.20f\n",scaling_factor);
+      fprintf(world->bayesfile, "# Scaling factor %20.20f\n",scaling_factor);
+    }
+  return scaling_factor;
+}
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 {
@@ -2403,7 +2433,6 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   static boolean done=FALSE;
 #endif
   long t;
-  const long np = EARTH->numpop2;
   const long hc = EARTH->options->heated_chains;
   long locus;
   const long maxreplicate = (options->replicate
@@ -2424,7 +2453,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   MYREAL asum = 0.;
   MYREAL lsum;
   MYREAL lsum0;
-
+  MYREAL scaling_factor = 0.0;
   // calculate the harmonic mean score
   for(locus=0;locus < EARTH->loci; locus++)
     {
@@ -2452,7 +2481,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	{
 	  if(EARTH->data->skiploci[locus])
 	    continue;
-
+	  
 	  lsum = 0.;
 	  lsum0 = 0.;
 #ifdef MPI
@@ -2460,12 +2489,12 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
 	  //	  if(!done)
 	  //  {
-	      for(t=0; t < hc; t++)
-		{
-		  EARTH->bf[locus * hc + t] /= maxreplicate;
-		}
-	      //      done=TRUE;
-	      //  }
+	  for(t=0; t < hc; t++)
+	    {
+	      //TEST	      EARTH->bf[locus * hc + t] /= maxreplicate;
+	    }
+	  //      done=TRUE;
+	  //  }
 #endif
 	  // from very hot to cold, the 
 	  for(t=1; t < hc; t++)
@@ -2533,32 +2562,15 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 		pdf_bayes_factor_rawscores(locus, lsum, lsum-lsum0+approxlsum, EARTH->hmscale[locus] - log (EARTH->hm[locus]));
 #endif
 	    }
-	  bfsum2 += approxlsum + lsum - lsum0;  
-	  
+	  bfsum2 += approxlsum + lsum - lsum0;  	  
 	  bfsum += lsum; //+ EARTH->bfscale[locus];
 	}
       if(EARTH->loci>1)
 	{
-#ifndef OLDBF
-	  long pop;
-	  long i;
-	  MYREAL scaling_factor=0.0;
-	  for(i=0;i<np;i++)
-	    {
-	      if(EARTH->bayes->map[i][1] == INVALID)
-		continue;
-	      else
-		{
-		  pop  = EARTH->bayes->map[i][1];
-		}
-	      scaling_factor += exp(EARTH->bayes->scaling_factors[pop] - EARTH->bayes->maxmaxvala);
-	      printf("%f\n",scaling_factor);
-	    }
-	  scaling_factor = log(scaling_factor) + EARTH->bayes->maxmaxvala;
-	  // printf("%f\n",scaling_factor);
-	  bfsum += scaling_factor;
+	  scaling_factor = combine_scaling_factor(EARTH);
+	  bfsum  += scaling_factor;
 	  bfsum2 += scaling_factor;
-#endif
+	  hsum   += scaling_factor;
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
 	  fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n", bfsum, bfsum2, hsum); 
 #ifdef PRETTY
@@ -2566,13 +2578,13 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	    pdf_bayes_factor_rawscores(-1, bfsum, bfsum2, hsum);
 #endif
 	}
-     else 
-       {
-	 fprintf(file,"\n\n(1a) Thermodynamic integration: log(Prob(D|Model))=%f (%f with Bezier-approximation[1b]) %s\n", bfsum, bfsum2,  
-		 options->adaptiveheat!=NOTADAPTIVE ? "(adaptive heating -> value may most likely be wrong)" : "");
-	 fprintf(file,"(2) Harmonic mean:             log(Prob(D|Model))=%f\n",hsum);
-	 fprintf(file,"(1) and (2) should give a similar result, (2) is considered more\ncrude than (1), but (1) needs heating with several well-spaced chains\n\n");
-       }
+      else 
+	{
+	  fprintf(file,"\n\n(1a) Thermodynamic integration: log(Prob(D|Model))=%f (%f with Bezier-approximation[1b]) %s\n", bfsum, bfsum2,  
+		  options->adaptiveheat!=NOTADAPTIVE ? "(adaptive heating -> value may most likely be wrong)" : "");
+	  fprintf(file,"(2) Harmonic mean:             log(Prob(D|Model))=%f\n",hsum);
+	  fprintf(file,"(1) and (2) should give a similar result, (2) is considered more\ncrude than (1), but (1) needs heating with several well-spaced chains\n\n");
+	}
     }
   else   // -----------------------------------------not heating
     {
@@ -2591,6 +2603,8 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	}
       if(EARTH->loci>1)
 	{
+	  scaling_factor = combine_scaling_factor(EARTH);
+	  hsum += scaling_factor;
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
 	  fprintf(file,"      All           ------                           ------            %12.2f\n", hsum); 
 #ifdef PRETTY
