@@ -11,12 +11,12 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: mcmc.h 992 2007-10-23 14:23:11Z beerli $
+$Id: mcmc.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 extern long tree_update (world_fmt * world, long g);
