@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1564 2009-08-01 00:30:52Z beerli $
+  $Id: migration.h 1593 2009-12-06 22:42:27Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -89,14 +89,12 @@ typedef struct _burnin_record_fmt
 typedef struct _beagle_fmt {
   boolean instance;
   int *instance_handle; // indicator to the workorder for the GPU/CPU likelihood calculation
-  int *instance_handle1; // 
-  int *instance_handle2; // 
   int numallocpartials;
   int numpartials;
-  double *partials; //  conditional likelihood for each site for each parent, leftchild, rightchild
+  double *partials; //  conditional likelihood for each site 
   int  numallocallyweights; // pattern weighting
   int *allyweights;// pattern weighting
-  double *weights; //????
+  double *weights; // these are the probabilities of the site rates (should move out to mutationmodels)
 
   int numallocbranches;
   int numbranches;
@@ -106,22 +104,6 @@ typedef struct _beagle_fmt {
   int numoperations;
   int *operations;  // holds the operation for each parent,leftchild,lefttransitionmatrix,rightchild,rightt.. 
 
-  int numallocbranches1;
-  int numbranches1;
-  double *branch_lengths1; // branchlengths for (for each edge leading to a child)
-  int *branch_indices1;    // indicator for transition matices
-  int numallocoperations1;
-  int numoperations1;
-  int *operations1;  // holds the operation for each parent,leftchild,lefttransitionmatrix,rightchild,rightt.. 
-
-  int numallocbranches2;
-  int numbranches2;
-  double *branch_lengths2; // branchlengths for (for each edge leading to a child)
-  int *branch_indices2;    // indicator for transition matices
-  int numallocoperations2;
-  int numoperations2;
-  int *operations2;  // holds the operation for each parent,leftchild,lefttransitionmatrix,rightchild,rightt.. 
-
   int *scalingfactorsindices;
   int scalingfactorscount;
 
@@ -239,6 +221,8 @@ typedef struct seqmodel_fmt
   long *location;                         //
   long addon;                             //
   boolean *links;                         //!< information about link status of locus
+  long *savealiasweight;                 //!< keeps a savecopy of the aliasweights
+  boolean done;
 }
 seqmodel_fmt;
 
@@ -288,6 +272,9 @@ typedef struct _data
   char *locitypes;          //!< holds all datatypes for each locus, options->datatype is the default
   char **locusname;
   long *subloci;            //!< holds the number of strictly linked "loci" that make up the locus for migrate
+  long numdatatypealloc;
+  long numsublocialloc;
+  long numlocitypesalloc;
 }
 data_fmt;
 
@@ -352,6 +339,9 @@ typedef struct _bayes
   boolean mu;
   long mdiminterval ; // interval at which the whole parameter list is printed to file
   int prettyhist;
+  MYREAL *scaling_factors;
+  MYREAL *histtotal;
+  MYREAL maxmaxvala;
 }
 bayes_fmt;
 
@@ -595,6 +585,12 @@ typedef struct _option
   long mutationrate_year_numalloc; // 
   MYREAL generation_year;
   long randomsubset;
+#ifdef SEASON
+  MYREAL *timings; // vector of time points (options)
+  long numtimings; // number of elements in the timings vector
+  MYREAL **timemodifiers; // vector of parameter modifier vectors
+#endif
+
 }
 option_fmt;
 
@@ -605,7 +601,8 @@ typedef struct _mutationmodel {
   long numstates; // number of states in model: DNA=4, DNA+gap=5, msat>2
   double *basefreqs;
   long numsiterates;
-  double *sitesrates;
+  double *siterates;
+  double *siteprobs;
   char datatype; //specifices the model
   double *eigenvectormatrix;
   double *inverseeigenvectormatrix;
@@ -1178,6 +1175,11 @@ typedef struct _world
 #ifdef BEAGLE
   beagle_fmt *beagle;
 #endif
+#ifdef SEASON
+  MYREAL *timings; // vector of time points
+  long numtimings; // number of elements in the timings vector
+  MYREAL **timemodifiers; // vector of parameter modifier vectors
+#endif
 }
 world_fmt;
 
