@@ -88,4 +88,7 @@ extern void pdf_histogram_legend(void);
 
 // write PDF content to file
 extern int pdf_write_file(option_fmt *options);
+#ifndef HAVE_STRSEP
+char *strsep(char **, const char *);
+#endif
 #endif
