@@ -10,12 +10,12 @@
  R E P O R T E R   R O U T I N E S 
                                                                                                                
  Peter Beerli 1999, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: reporter.h 1244 2008-05-13 13:42:33Z beerli $
+$Id: reporter.h 1458 2008-11-28 02:38:18Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -27,7 +27,8 @@ extern void chain_means (MYREAL *thischainmeans, world_fmt * world);
 extern void convergence_progress(FILE *file, world_fmt *world);
 extern MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *autoc, MYREAL *effsample);
 extern boolean max_ess(const MYREAL * ess, const long n, const MYREAL minimum);
-extern void print_param_eff_size(FILE *file, world_fmt *world, long numparam, int offset, 
+extern void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset, 
 				 MYREAL *autocorr, MYREAL *effsample);
-extern void collect_eff_values(world_fmt *world);
+extern void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locus, MYREAL *autoc, MYREAL *effsample);
+extern void collect_ess_values(world_fmt *world);
 #endif
