@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1563 2009-07-30 18:28:33Z beerli $
+$Id: tools.c 1624 2010-02-05 21:02:19Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -37,6 +37,8 @@ $Id: tools.c 1563 2009-07-30 18:28:33Z beerli $
 #include "migrate_mpi.h"
 #include "options.h"
 #include "laguerre.h"
+#include "pretty.h"
+
 #include <stdio.h>
 #include <math.h>
 #ifdef DMALLOC_FUNC_CHECK
@@ -599,7 +601,7 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 	long i,j;
 #endif
     long maxfilenum = MYMAXFILENUM; //see definitions.h all files have a number and a filename;
-	tempdb = mycalloc(maxfilenum,sizeof(long));
+    tempdb = (long *) mycalloc(maxfilenum,sizeof(long));
 	
     if (myID == MASTER)
     {
@@ -1192,10 +1194,10 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
             FGETS (input, 1024, sumfile);
             if(input[0]=='M') // added custom migration model 11-25-02
               {
-                options->custm = myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
+                options->custm = (char *) myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
                 strcpy(options->custm,input+6);
                 FGETS (input, 1024, sumfile);
-                options->custm2 = myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
+                options->custm2 = (char *) myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
                 strcpy(options->custm2,input+6);
                 FGETS (input, 1024, sumfile);
               }
